exceptiontools.MissingInstrumentError
=====================================

.. abjad-lineage:: abjad.tools.exceptiontools.MissingInstrumentError.MissingInstrumentError

.. autoclass:: abjad.tools.exceptiontools.MissingInstrumentError.MissingInstrumentError
   :noindex:

Special Methods
---------------

.. automethod:: abjad.tools.exceptiontools.MissingInstrumentError.MissingInstrumentError.__delattr__
   :noindex:

.. automethod:: abjad.tools.exceptiontools.MissingInstrumentError.MissingInstrumentError.__getitem__
   :noindex:

.. automethod:: abjad.tools.exceptiontools.MissingInstrumentError.MissingInstrumentError.__getslice__
   :noindex:

.. automethod:: abjad.tools.exceptiontools.MissingInstrumentError.MissingInstrumentError.__repr__
   :noindex:

.. automethod:: abjad.tools.exceptiontools.MissingInstrumentError.MissingInstrumentError.__setattr__
   :noindex:

.. automethod:: abjad.tools.exceptiontools.MissingInstrumentError.MissingInstrumentError.__setstate__
   :noindex:

.. automethod:: abjad.tools.exceptiontools.MissingInstrumentError.MissingInstrumentError.__str__
   :noindex:

.. automethod:: abjad.tools.exceptiontools.MissingInstrumentError.MissingInstrumentError.__unicode__
   :noindex:
